@@ -1,3 +1,5 @@
+safe_rl <- safely(readLines)
+
 #' Retrieve list of IPv4 "full bogons" from Team Cymru webservice
 #'
 #' The traditional bogon prefixes (IPV4), plus prefixes that have been allocated to
@@ -20,38 +22,64 @@
 #'        \code{NA} will be returned.
 #' @seealso \url{http://www.team-cymru.org/bogon-reference-http.html}
 #' @export
-#' @examples
+#' @examples \dontrun{
 #' v4_bogons <- ipv4_bogons()
 #' v4_bogons <- ipv4_bogons(cached_bogons=v4_bogons)
-ipv4_bogons <- function(force=FALSE, cached_bogons=NA_character_) {
-  bogons <- NA_character_
+#' }
+ipv4_bogons <- function(force=FALSE, cached_bogons=NA) {
+
+  BOGONS_URL <- "http://www.team-cymru.org/Services/Bogons/fullbogons-ipv4.txt"
+
   if (Sys.getenv("CYMRU_LAST_V4_BOGON") == "") {
-    tryCatch(
-      bogons <- readLines("http://www.team-cymru.org/Services/Bogons/fullbogons-ipv4.txt"),
-      error=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")},
-      warning=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")}
-    )
-    if (any(is.na(bogons))) return(cached_bogons)
-    last_updated <- as.numeric(str_match_all(bogons[1], "updated ([[:digit:]]+) ")[[1]][,2])
-    Sys.setenv(CYMRU_LAST_V4_BOGON=last_updated)
-    return(tail(bogons, -1))
-  } else {
-    delta <- (as.numeric(Sys.time()) - as.numeric(Sys.getenv("CYMRU_LAST_V4_BOGON")))
-    if ((delta > 14400) | ((delta < 14400) & force)) {
-      tryCatch(
-        bogons <- readLines("http://www.team-cymru.org/Services/Bogons/fullbogons-ipv4.txt"),
-        error=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")},
-        warning=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")}
-      )
-      if (any(is.na(bogons))) return(cached_bogons)
-      last_updated <- as.numeric(str_match_all(bogons[1], "updated ([[:digit:]]+) ")[[1]][,2])
-      Sys.setenv(CYMRU_LAST_V4_BOGON=last_updated)
-      return(tail(bogons, -1))
-    } else {
-      message("It has not been 4 hours since the last refresh. Use 'force=TRUE' to force a refresh.")
-      return(cached_bogons)
+
+    bogons <- safe_rl(BOGONS_URL)
+
+    if (is.null(bogons$result)) {
+      message("Could not reach team-cymru.org")
+      return(NA_character_)
     }
+
+    bogons <- bogons$result
+
+    last_updated <- as.numeric(str_match_all(bogons[1],
+                                             "updated ([[:digit:]]+) ")[[1]][,2])
+
+    Sys.setenv(CYMRU_LAST_V4_BOGON=last_updated)
+
+    return(tail(bogons, -1))
+
+  } else {
+
+    delta <- (as.numeric(Sys.time()) - as.numeric(Sys.getenv("CYMRU_LAST_V4_BOGON")))
+
+    if ((delta > 14400) | ((delta < 14400) & force)) {
+
+      bogons <- safe_rl(BOGONS_URL)
+
+      if (is.null(bogons$result)) {
+        message("Could not reach team-cymru.org")
+        return(NA_character_)
+      }
+
+      bogons <- bogons$result
+
+      last_updated <- as.numeric(str_match_all(bogons[1],
+                                               "updated ([[:digit:]]+) ")[[1]][,2])
+
+      Sys.setenv(CYMRU_LAST_V4_BOGON=last_updated)
+
+      return(tail(bogons, -1))
+
+    } else {
+
+      message("It has not been 4 hours since the last refresh. Use 'force=TRUE' to force a refresh.")
+
+      return(cached_bogons)
+
+    }
+
   }
+
 }
 
 #' Retrieve list of IPv6 "full bogons" from Team Cymru webservice
@@ -76,36 +104,61 @@ ipv4_bogons <- function(force=FALSE, cached_bogons=NA_character_) {
 #'        \code{NA} will be returned.
 #' @seealso \url{http://www.team-cymru.org/bogon-reference-http.html}
 #' @export
-#' @examples
+#' @examples \dontrun{
 #' v6_bogons <- ipv6_bogons()
 #' v6_bogons <- ipv6_bogons(cached_bogons=v6_bogons)
-ipv6_bogons <- function(force=FALSE, cached_bogons=NA_character_) {
-  bogons <- NA_character_
+#' }
+ipv6_bogons <- function(force=FALSE, cached_bogons=NA) {
+
+  FULL_BOGONS_URL <- "http://www.team-cymru.org/Services/Bogons/fullbogons-ipv6.txt"
+
   if (Sys.getenv("CYMRU_LAST_V6_BOGON") == "") {
-    tryCatch(
-      bogons <- readLines("http://www.team-cymru.org/Services/Bogons/fullbogons-ipv6.txt"),
-      error=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")},
-      warning=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")}
-    )
-    if (any(is.na(bogons))) return(cached_bogons)
-    last_updated <- as.numeric(str_match_all(bogons[1], "updated ([[:digit:]]+) ")[[1]][,2])
-    Sys.setenv(CYMRU_LAST_V6_BOGON=last_updated)
-    return(tail(bogons, -1))
-  } else {
-    delta <- (as.numeric(Sys.time()) - as.numeric(Sys.getenv("CYMRU_LAST_V6_BOGON")))
-    if ((delta > 14400) | ((delta < 14400) & force)) {
-      tryCatch(
-        bogons <- readLines("http://www.team-cymru.org/Services/Bogons/fullbogons-ipv6.txt"),
-        error=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")},
-        warning=function(e) {message("Error reported by Team Cymru service. Will return cached bogons.")}
-      )
-      if (any(is.na(bogons))) return(cached_bogons)
-      last_updated <- as.numeric(str_match_all(bogons[1], "updated ([[:digit:]]+) ")[[1]][,2])
-      Sys.setenv(CYMRU_LAST_V6_BOGON=last_updated)
-      return(tail(bogons, -1))
-    } else {
-      message("It has not been 4 hours since the last refresh. Use 'force=TRUE' to force a refresh.")
-      return(cached_bogons)
+
+    bogons <- safe_rl(FULL_BOGONS_URL)
+
+    if (is.null(bogons$result)) {
+      message("Could not reach team-cymru.org")
+      return(NA_character_)
     }
+
+    bogons <- bogons$result
+
+    last_updated <- as.numeric(str_match_all(bogons[1],
+                                             "updated ([[:digit:]]+) ")[[1]][,2])
+
+    Sys.setenv(CYMRU_LAST_V6_BOGON=last_updated)
+
+    return(tail(bogons, -1))
+
+  } else {
+
+    delta <- (as.numeric(Sys.time()) - as.numeric(Sys.getenv("CYMRU_LAST_V6_BOGON")))
+
+    if ((delta > 14400) | ((delta < 14400) & force)) {
+
+      bogons <- safe_rl(FULL_BOGONS_URL)
+
+      if (is.null(bogons$result)) {
+        message("Could not reach team-cymru.org")
+        return(NA_character_)
+      }
+
+      bogons <- bogons$result
+
+      last_updated <- as.numeric(str_match_all(bogons[1],
+                                               "updated ([[:digit:]]+) ")[[1]][,2])
+
+      Sys.setenv(CYMRU_LAST_V6_BOGON=last_updated)
+
+      return(tail(bogons, -1))
+
+    } else {
+
+      message("It has not been 4 hours since the last refresh. Use 'force=TRUE' to force a refresh.")
+
+      return(cached_bogons)
+
+    }
+
   }
 }
